OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Atsisakyta (Paveldėtas leidimas)",
    "Allowed (Inherited permission)" : "Leista (Paveldėtas leidimas)",
    "Allowed" : "Leista",
    "Access denied" : "Prieiga negalima",
    "Access allowed" : "Prieiga leidžiama",
    "Inherit permission" : "Paveldėti leidimą",
    "Deny" : "Drausti",
    "Allow" : "Leisti",
    "Group" : "Grupė",
    "Team" : "Komanda",
    "Read" : "Skaityti",
    "Write" : "Rašyti",
    "Create" : "Sukurti",
    "Delete" : "Ištrinti",
    "Share" : "Bendrinti",
    "You" : "Jūs",
    "Remove access rule" : "Šalinti prieigos taisyklę",
    "Select a user or group" : "Pasirinkti naudotoją ar grupę",
    "Add group" : "Pridėti grupę",
    "Default" : "Numatytasis",
    "Unlimited" : "Neribotai",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Ar tikrai norite ištrinti „{folderName}“ ir visus jame esančius failus? Šios operacijos nebeįmanoma bus atšaukti",
    "Delete \"{folderName}\"?" : "Ištrinti „{folderName}“?",
    "Group or team" : "Grupė ar komanda",
    "Folder name" : "Aplanko pavadinimas",
    "Quota" : "Leidžiamas duomenų kiekis",
    "Advanced Permissions" : "Išplėstiniai leidimai",
    "Previous" : "Ankstesnis",
    "Next" : "Kitas",
    "User" : "Naudotojas",
    "Unknown" : "Nežinoma",
    "None" : "Nėra",
    "{displayName} (team)" : "{displayName} (komanda)",
    "Add group or team" : "Pridėti grupę ar komandą",
    "{size} used" : "{size} naudojama",
    "Unset" : "Nenustatyta"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
